@@ -17,6 +17,7 @@ class Guester(Video):
     c_guester = None
     p_guester = None
     str_show = ""
+    img1 = 0
     
     def __init__(self):
 #         super(Guester,self).__init__()
@@ -71,16 +72,16 @@ class Guester(Video):
     def get_gesture_img(self):
         
         while True:
-            success,img = self.cap.read()
+            success,self.img1 = self.cap.read()
             if not success:
                 continue
-            image_height,image_width,_ = np.shape(img)
-            imgRGB = cv2.cvtColor(img,cv2.COLOR_BGR2RGB)
+            image_height,image_width,_ = np.shape(self.img1)
+            imgRGB = cv2.cvtColor(self.img1,cv2.COLOR_BGR2RGB)
             results = self.hands.process(imgRGB)
             
             if results.multi_hand_landmarks:
                 hand = results.multi_hand_landmarks[0]
-                self.mpDraw.draw_landmarks(img,hand,self.mpHands.HAND_CONNECTIONS)
+                self.mpDraw.draw_landmarks(self.img1,hand,self.mpHands.HAND_CONNECTIONS)
                 list_lms = []
                 for i in range(21):
                     pos_x = hand.landmark[i].x*image_width
@@ -88,16 +89,16 @@ class Guester(Video):
                     list_lms.append([int(pos_x),int(pos_y)])
                 
                 list_lms = np.array(list_lms,dtype = np.int32)
-                self.c_guester = self.get_guester(img,list_lms)
+                self.c_guester = self.get_guester(self.img1,list_lms)
                 
                 if not self.c_guester is None and self.c_guester != self.p_guester:
                     self.p_guester = self.c_guester
             if not self.p_guester is None:
                 self.str_show = ' %s'%(self.dic_guester[self.p_guester])
-            img = self.paint_chinese_opencv(img,self.str_show,(10,10),(0,255,255),font_size=30)
+            self.img1 = self.paint_chinese_opencv(self.img1,self.str_show,(10,10),(0,255,255),font_size=30)
 
         
-            return self.p_guester, img
+            return self.p_guester
         cap.release()
          
     def gesture_web_video(self):
@@ -143,8 +144,8 @@ class Guester(Video):
             ret,jpeg = cv2.imencode('.jpg',img)
             yield(b'--frame\r\n'+b'Content-Type:image/jpeg\r\n\r\n'+jpeg.tobytes()+b'\r\n\r\n')
     
-    def cv2_show(self,name,img):
-        cv2.imshow(name,img)
+    def cv2_show(self,name):
+        cv2.imshow(name,self.img1)
         cv2.waitKey(1)
         
     def img_encode(self,img):
